@@ -1,24 +1,15 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005-2007 Olivier Goffart <ogoffart at kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005-2007 Olivier Goffart <ogoffart at kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
-#include "knotifyconfigactionswidget.h"
-#include "knotifyconfigelement.h"
 
-#include <QDebug>
+#include "knotifyconfigactionswidget.h"
+
+#include "knotifyconfigelement.h"
+#include <knotifyconfig_debug.h>
+
 #include <QStandardPaths>
 
 #if defined(HAVE_CANBERRA)
@@ -165,7 +156,7 @@ void KNotifyConfigActionsWidget::slotPlay()
     if (!m_context) {
         int ret = ca_context_create(&m_context);
         if (ret != CA_SUCCESS) {
-            qWarning() << "Failed to initialize canberra context for audio notification:" << ca_strerror(ret);
+            qCWarning(KNOTIFYCONFIG_LOG) << "Failed to initialize canberra context for audio notification:" << ca_strerror(ret);
             m_context = nullptr;
             return;
         }
@@ -182,7 +173,7 @@ void KNotifyConfigActionsWidget::slotPlay()
             CA_PROP_APPLICATION_ICON_NAME, qUtf8Printable(qApp->windowIcon().name()),
             nullptr);
         if (ret != CA_SUCCESS) {
-            qWarning() << "Failed to set application properties on canberra context for audio notification:" << ca_strerror(ret);
+            qCWarning(KNOTIFYCONFIG_LOG) << "Failed to set application properties on canberra context for audio notification:" << ca_strerror(ret);
         }
     }
 
@@ -199,7 +190,7 @@ void KNotifyConfigActionsWidget::slotPlay()
     ca_proplist_destroy(props);
 
     if (ret != CA_SUCCESS) {
-        qWarning() << "Failed to play sound with canberra:" << ca_strerror(ret);
+        qCWarning(KNOTIFYCONFIG_LOG) << "Failed to play sound with canberra:" << ca_strerror(ret);
         return;
     }
 #elif defined(HAVE_PHONON)
@@ -212,5 +203,5 @@ void KNotifyConfigActionsWidget::slotPlay()
 void KNotifyConfigActionsWidget::slotTTSComboChanged()
 {
     m_ui.TTS_select->setEnabled(m_ui.TTS_check->isChecked() &&  m_ui.TTS_combo->currentIndex() == 2);
-    emit changed();
+    Q_EMIT changed();
 }
